Keypair

Struct Keypair 

pub struct Keypair(/* private fields */);
Ed25519 keypair to sign dns Packets.

Implementations

Source

impl Keypair

pub fn to_rpk_certified_key(&self) -> CertifiedKey

Return a RawPublicKey certified key according to RFC 7250 useful to use with rustls::ConfigBuilder::with_cert_resolver and rustls::server::AlwaysResolvesServerRawPublicKeys

pub fn to_rpk_rustls_server_config(&self) -> ServerConfig

Create a rustls::ServerConfig using this keypair as a RawPublicKey certificate according to RFC 7250

Source

impl Keypair

pub fn random() -> Keypair

Generates a new random Keypair using the operating system’s CSPRNG.

pub fn from_secret_key(secret_key: &[u8; 32]) -> Keypair

Creates a Keypair from a given SecretKey.

pub fn sign(&self, message: &[u8]) -> Signature

Signs a message with the private key of this Keypair.

pub fn verify(&self, message: &[u8], signature: &Signature) -> Result<(), Error>

Verifies a message against a given signature using this Keypair.

pub fn secret_key(&self) -> [u8; 32]

Returns the secret part of this Keypair.

pub fn public_key(&self) -> PublicKey

Returns the PublicKey of this Keypair.

pub fn to_z32(&self) -> String

Converts the public key of this Keypair to a z-base32 encoded string.

pub fn to_uri_string(&self) -> String

Converts the public key of this Keypair to a URI string.